==> bigdata-common-0.0.217-sources.jar: cn/com/duiba/bigdata/common/biz/enums/HourRediskeys.java <==
package cn.com.duiba.bigdata.common.biz.enums;

import cn.com.duiba.bigdata.common.biz.constant.TimeoutKeys;

public enum HourRediskeys {

    //广告 排除直投互动和直投页,
    H102(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx创意(条件12)
    H108(TimeoutKeys.TIMEOUT_8_HOUR),

    //素材id
    H109(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 直投
    H120(TimeoutKeys.TIMEOUT_8_HOUR),

    //创意素材 排除直投
    H121(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+广告发券次数 排除直投互动和直投页
    H202(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 + 媒体
    H203(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体 排除直投互动和直投页
    H204(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+广告位 排除直投互动和直投页
    H206(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+活动 排除直投互动和直投页
    H208(TimeoutKeys.TIMEOUT_8_HOUR),

    //advertid_orientationid 广告 配置维度
    H211(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+配置 排除直投互动和直投页
    H212(TimeoutKeys.TIMEOUT_8_HOUR),

    //H219_slotId_SdkSlotActualAccType_yyyyMMddHH
    H219(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx创意，ctr预估区间
    H220(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx创意，过滤类型
    H221(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx创意+点击价值分层
    H222(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 配置 场景是predcvr > 0
    H223(TimeoutKeys.TIMEOUT_2_DAY),

    //素材 + 资源位
    H224(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告位+美团adx实验分组 美团算法调价
    H225(TimeoutKeys.TIMEOUT_4_DAY),

    //创意id + 百度app_id
    H226(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源位 + 百度app_id
    H227(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 + 计费点击
    H228(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体 直投
    H229(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+广告位 直投
    H230(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源位+创意素材 排除直投
    H231(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体+广告发券次数 排除直投互动和直投页
    H303(TimeoutKeys.TIMEOUT_8_HOUR),

    //媒体+广告+配置
    H310(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体+配置 排除直投互动和直投页
    H311(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+素材+广告发券次数 排除直投互动和直投页
    H315(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 + 广告配置 + 区间rank_score
    H324(TimeoutKeys.TIMEOUT_8_HOUR),

    //H327_slotId_SdkSlotActualAccType_materialId_yyyyMMddHH 广告位素材
    H327(TimeoutKeys.TIMEOUT_8_HOUR),

    //H328_slotId_SdkSlotActualAccType_materialId_yyyyMMddHH 券素材
    H328(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx资源位+点击价值分层+adx交易类型
    H329(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx资源位 + adx预估区间 + adx交易类型
    H330(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 配置 模型id 场景是predcvr > 0
    H331(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告位+广告+美团adx实验分组
    H332(TimeoutKeys.TIMEOUT_4_DAY),

    //广告+配置+实验组拓量
    H333(TimeoutKeys.TIMEOUT_8_HOUR),

    //创意id + 百度appId + adx策略出价
    H334(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体+广告发券次数+素材 排除直投互动和直投页
    H401(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 +广告配置 + 媒体  + 区间
    H404(TimeoutKeys.TIMEOUT_8_HOUR),

    // H405_slot_id_dsm2_a_plug_id_plug_fre
    H405(TimeoutKeys.TIMEOUT_8_HOUR),

    // H406_slot_id_dsm2_a_plug_id_plug_fre
    H406(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+配置+媒体+实验组拓量
    H409(TimeoutKeys.TIMEOUT_4_DAY),

    //广告+配置+实验组+ocpc拓量
    H410(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+配置+媒体+实验组+ocpc拓量
    H502(TimeoutKeys.TIMEOUT_8_HOUR),

    ///广告 + 广告位 + 广告发券次数 + 素材(条件1)
    H1001(TimeoutKeys.TIMEOUT_8_HOUR),

    ///广告 + 广告位 + 广告发券次数 (条件1)
    H1002(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx计划  +  创意素材
    H1003(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx计划 + 实验id  + 实验组  关闭冷启动  coldstart=0
    H1004(TimeoutKeys.TIMEOUT_8_HOUR),

    //计划+ 联盟媒体 + 实验id + 实验分组 关闭冷启动  coldstart=0
    H1005(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源 + 实验id  + 实验分组 关闭冷启动  coldstart=0
    H1006(TimeoutKeys.TIMEOUT_8_HOUR),

    //计划+ 联盟媒体行业（ext_app_trade） +实验id + 实验分组  关闭冷启动  coldstart=0
    H1008(TimeoutKeys.TIMEOUT_8_HOUR),

    //素材创意
    H1009(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源位 +  流量聚合id + 实验id + 实验组
    H1010(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源位
    H1011(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告
    H1012(TimeoutKeys.TIMEOUT_8_HOUR),

    //计划（首张券）
    H1013(TimeoutKeys.TIMEOUT_8_HOUR),

    //计划 + adx分区桶
    H1014(TimeoutKeys.TIMEOUT_8_HOUR);


    private final int timeout;

    private HourRediskeys(int timeout) {
        this.timeout = timeout;
    }

    public int getTimeout() {
        return timeout;
    }

    public String getPrefix() {
        return super.toString();
    }

    @Override
    public String toString() {
        return super.toString() + "_";
    }
}

==> bigdata-common-0.1.44-sources.jar: cn/com/duiba/bigdata/common/biz/enums/HourRediskeys.java <==
package cn.com.duiba.bigdata.common.biz.enums;

import cn.com.duiba.bigdata.common.biz.constant.TimeoutKeys;

public enum HourRediskeys {

    //广告 排除直投互动和直投页,
    H102(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx创意(条件12)
    H108(TimeoutKeys.TIMEOUT_8_HOUR),

    //素材id
    H109(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 直投
    H120(TimeoutKeys.TIMEOUT_8_HOUR),

    //创意素材 排除直投
    H121(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+广告发券次数 排除直投互动和直投页
    H202(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 + 媒体
    H203(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体 排除直投互动和直投页
    H204(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+广告位 排除直投互动和直投页
    H206(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+活动 排除直投互动和直投页
    H208(TimeoutKeys.TIMEOUT_8_HOUR),

    //advertid_orientationid 广告 配置维度
    H211(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+配置 排除直投互动和直投页
    H212(TimeoutKeys.TIMEOUT_8_HOUR),

    //H219_slotId_SdkSlotActualAccType_yyyyMMddHH
    H219(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx创意，ctr预估区间
    H220(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx创意，过滤类型
    H221(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx创意+点击价值分层
    H222(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 配置 场景是predcvr > 0
    H223(TimeoutKeys.TIMEOUT_2_DAY),

    //素材 + 资源位
    H224(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告位+美团adx实验分组 美团算法调价
    H225(TimeoutKeys.TIMEOUT_4_DAY),

    //创意id + 百度app_id
    H226(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源位 + 百度app_id
    H227(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 + 计费点击
    H228(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体 直投
    H229(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+广告位 直投
    H230(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源位+创意素材 排除直投
    H231(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体+广告发券次数 排除直投互动和直投页
    H303(TimeoutKeys.TIMEOUT_8_HOUR),

    //媒体+广告+配置
    H310(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体+配置 排除直投互动和直投页
    H311(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+素材+广告发券次数 排除直投互动和直投页
    H315(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 + 广告配置 + 区间rank_score
    H324(TimeoutKeys.TIMEOUT_8_HOUR),

    //H327_slotId_SdkSlotActualAccType_materialId_yyyyMMddHH 广告位素材
    H327(TimeoutKeys.TIMEOUT_8_HOUR),

    //H328_slotId_SdkSlotActualAccType_materialId_yyyyMMddHH 券素材
    H328(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx资源位+点击价值分层+adx交易类型
    H329(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx资源位 + adx预估区间 + adx交易类型
    H330(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 配置 模型id 场景是predcvr > 0
    H331(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告位+广告+美团adx实验分组
    H332(TimeoutKeys.TIMEOUT_4_DAY),

    //广告+配置+实验组拓量
    H333(TimeoutKeys.TIMEOUT_8_HOUR),

    //创意id + 百度appId + adx策略出价
    H334(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+媒体+广告发券次数+素材 排除直投互动和直投页
    H401(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告 +广告配置 + 媒体  + 区间
    H404(TimeoutKeys.TIMEOUT_8_HOUR),

    // H405_slot_id_dsm2_a_plug_id_plug_fre
    H405(TimeoutKeys.TIMEOUT_8_HOUR),

    // H406_slot_id_dsm2_a_plug_id_plug_fre
    H406(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+配置+媒体+实验组拓量
    H409(TimeoutKeys.TIMEOUT_4_DAY),

    //广告+配置+实验组+ocpc拓量
    H410(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告+配置+媒体+实验组+ocpc拓量
    H502(TimeoutKeys.TIMEOUT_8_HOUR),

    ///广告 + 广告位 + 广告发券次数 + 素材(条件1)
    H1001(TimeoutKeys.TIMEOUT_8_HOUR),

    ///广告 + 广告位 + 广告发券次数 (条件1)
    H1002(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx计划  +  创意素材
    H1003(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx计划 + 实验id  + 实验组  关闭冷启动  coldstart=0
    H1004(TimeoutKeys.TIMEOUT_8_HOUR),

    //计划+ 联盟媒体 + 实验id + 实验分组 关闭冷启动  coldstart=0
    H1005(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源 + 实验id  + 实验分组 关闭冷启动  coldstart=0
    H1006(TimeoutKeys.TIMEOUT_8_HOUR),

    //计划+ 联盟媒体行业（ext_app_trade） +实验id + 实验分组  关闭冷启动  coldstart=0
    H1008(TimeoutKeys.TIMEOUT_8_HOUR),

    //素材创意
    H1009(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源位 +  流量聚合id + 实验id + 实验组
    H1010(TimeoutKeys.TIMEOUT_8_HOUR),

    //资源位
    H1011(TimeoutKeys.TIMEOUT_8_HOUR),

    //广告
    H1012(TimeoutKeys.TIMEOUT_8_HOUR),

    //计划（首张券）
    H1013(TimeoutKeys.TIMEOUT_8_HOUR),

    //计划 + adx分区桶
    H1014(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx资源位 + 创意计划 + 联盟媒体 + 联盟广告位
    H1015(TimeoutKeys.TIMEOUT_8_HOUR),

    //adx资源位 + 联盟媒体 + 联盟广告位
    H1016(TimeoutKeys.TIMEOUT_8_HOUR)






    ;


    private final int timeout;

    private HourRediskeys(int timeout) {
        this.timeout = timeout;
    }

    public int getTimeout() {
        return timeout;
    }

    public String getPrefix() {
        return super.toString();
    }

    @Override
    public String toString() {
        return super.toString() + "_";
    }
}
